maxGenerations property
The most assets a single render may generate (cache hits do not count), or
null for no limit.
Implementation
final int? maxGenerations;
The most assets a single render may generate (cache hits do not count), or
null for no limit.
final int? maxGenerations;